Package: tipsae
Title: Tools for Handling Indices and Proportions in Small Area
        Estimation
Version: 1.0.3
Authors@R: 
    c(person(given = "Silvia",
           family = "De Nicolò",
           role = c("aut", "cre"),
           email = "silvia.denicolo@unibo.it",
           comment = c(ORCID = "0000-0001-5052-6527")), 
           person(given = "Aldo",
           family = "Gardini",
           role = c("aut"),
           email = "aldo.gardini@unibo.it",
           comment = c(ORCID = "0000-0002-2164-5815")))
Description: It allows for mapping proportions and indicators defined on the unit interval. It implements Beta-based small area methods comprising the classical Beta regression models, the Flexible Beta model and Zero and/or One Inflated extensions (Janicki 2020 <doi:10.1080/03610926.2019.1570266>). Such methods, developed within a Bayesian framework through Stan <https://mc-stan.org/>, come equipped with a set of diagnostics and complementary tools, visualizing and exporting functions. A Shiny application with a user-friendly interface can be launched to further simplify the process. For further details, refer to De Nicolò and Gardini (2024 <doi:10.18637/jss.v108.i01>).
License: GPL-3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.2
VignetteBuilder: R.rsp
RdMacros: Rdpack
Biarch: true
NeedsCompilation: yes
Depends: R (>= 3.5.0), shiny (>= 1.0.3)
Imports: methods, Rcpp (>= 0.12.0), rstan (>= 2.26.0), ggplot2 (>=
        3.3.2), nlme (>= 3.1.152), stats, sp, ggpubr, Rdpack
Suggests: rstantools (>= 2.1.1), RcppParallel (>= 5.0.1), callr, sf,
        dplyr, leaflet, tmap, spam, spdep, gridExtra (>= 2.3), R.rsp,
        shinythemes, shinyFeedback, shinybusy, shinyWidgets, shinyjs,
        bayesplot, DT (>= 0.32.1), loo (>= 2.3.1)
LinkingTo: BH (>= 1.66.0), Rcpp (>= 0.12.0), RcppEigen (>= 0.3.3.3.0),
        RcppParallel (>= 5.0.1), rstan (>= 2.26.0), StanHeaders (>=
        2.26.0)
SystemRequirements: GNU make
Packaged: 2024-09-13 14:15:33 UTC; aldo.gardini2
Author: Silvia De Nicolò [aut, cre] (<https://orcid.org/0000-0001-5052-6527>),
  Aldo Gardini [aut] (<https://orcid.org/0000-0002-2164-5815>)
Maintainer: Silvia De Nicolò <silvia.denicolo@unibo.it>
Repository: CRAN
Date/Publication: 2024-09-13 14:40:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-05-01 05:23:43 UTC; unix
Archs: tipsae.so.dSYM
