# Generated by roxygen2: do not edit by hand

S3method(density,summary_fitsae)
S3method(plot,benchmark_fitsae)
S3method(plot,smoothing_fitsae)
S3method(plot,summary_fitsae)
S3method(print,benchmark_fitsae)
S3method(print,estimates_fitsae)
S3method(print,fitsae)
S3method(print,smoothing_fitsae)
S3method(print,summary_fitsae)
S3method(summary,fitsae)
export(benchmark)
export(export)
export(extract)
export(fit_sae)
export(map)
export(runShiny_tipsae)
export(smoothing)
import(Rcpp)
import(methods)
import(shiny)
importFrom(Rdpack,reprompt)
importFrom(grDevices,devAskNewPage)
importFrom(rstan,sampling)
importFrom(stats,as.formula)
importFrom(stats,complete.cases)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,model.extract)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,na.pass)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(utils,write.csv)
useDynLib(tipsae, .registration = TRUE)
